@@ -165,7 +165,7 @@ void LsWeather::onProcessFinished(int exitCode, QProcess::ExitStatus)
         qDebug() << "Update time:" << m_LastUpdate;
 
         QStringList lines = output.split("\n");
-        foreach (QString l, lines){
+        foreach (const QString l, lines){
             QStringList ele = l.split(" ", QString::SkipEmptyParts);
             if (ele.count() >= 2){
                 QString name = ele.at(0).toLower();
