@@ -77,6 +77,12 @@ QPoint LsWidget::getPosSetting(QString name, QPoint defaultValue)
     return defaultValue;
 }
 
+qreal LsWidget::getRotationSetting(qreal defaultValue)
+{
+    QString name = isPortrait() ? "RotationP" : "RotationL";
+    return getSetting(name, defaultValue).toReal();
+}
+
 QSize LsWidget::getSizeSetting(QSize defaultValue)
 {
     QString name = isPortrait() ? "SizeP" : "SizeL";
@@ -251,4 +257,5 @@ void LsWidget::setSizeAndPosition(QSize defaultSize, QPoint defaultPos)
 {
     setSize(getSizeSetting(defaultSize));
     setPos(getPosSetting(defaultPos));
+    setRotation(getRotationSetting(0));
 }
